.. _advanced-guide-index:

###############
Advanced Guide
###############

.. htmlonly::

    :Release: |version|
    :Date: |today|

.. toctree::
    :maxdepth: 2

    artists.rst
    gridspec.rst
    tight_layout_guide.rst
    event_handling.rst
    transforms_tutorial.rst
    path_tutorial.rst
    patheffects_guide.rst
    recipes.rst

